package com.bjlt.spider.business;

import com.alibaba.fastjson.JSON;
import com.bjlt.spider.business.Jinair.service.JinairService;
import com.bjlt.spider.business.airasia.service.AirAsiaWebService;
import com.bjlt.spider.business.airasia.service.AirasiaBigAppService;
import com.bjlt.spider.business.cebupacificair.service.CebupacificairService;
import com.bjlt.spider.business.lionair.service.LionairService;
import com.bjlt.spider.business.lionairthai.service.LionairthaiService;
import com.bjlt.spider.business.ryanair.service.RyanairWebService;
import com.bjlt.spider.business.vietjetair.service.VietjetairAPPService;
import com.bjlt.spider.business.vietjetair.service.VietjetairMobileService;
import com.bjlt.spider.config.Config;
import com.bjlt.spider.config.RedisReceiver;
import com.bjlt.spider.entity.SearchRequestEntity;
import com.bjlt.spider.entity.SearchResponseEntity;
import com.bjlt.spider.entity.SourceEnum;
import com.bjlt.spider.entity.monitor.MonitorEntity;
import com.bjlt.spider.monitor.utils.CallBackUtils;
import com.bjlt.spider.util.MethodType;
import com.bjlt.spider.util.RespEntity;
import com.luyn.core.RandomUtil;
import com.luyn.core.StringUtil;
import com.luyn.log.SysLogger;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;

/**
 * @author: luyanan0718@163.com
 * @create :2018/4/8 10:58
 * @introduce : 根据请求的airasia 进行航司的选择
 **/

@Component
@Slf4j
public class AirChooseUtils {
    private static final SysLogger logger = SysLogger.getSysLogger(RedisReceiver.class);

    @Autowired
    AirAsiaWebService airAsiaWebService;

    @Autowired
    VietjetairMobileService vietjetairMobileService;


    @Autowired
    VietjetairAPPService vietjetairAPPService;

    @Autowired
    Config config;


    @Autowired
    AirasiaBigAppService airasiaBigAppService;

    @Autowired
    LionairthaiService lionairthaiService;

    @Autowired
    LionairService lionairService;

    @Autowired
    JinairService jinairService;
    @Autowired
    CebupacificairService cebupacificairService;


    @Autowired
    RyanairWebService ryanairWebService;


    public RespEntity workers(SearchRequestEntity searchRequestEntity) {
        if (StringUtil.isBlank(searchRequestEntity.getAirSource())) {
            return RespEntity.error("airSource 不能为空");
        }
        MonitorEntity monitorEntity = new MonitorEntity();
        monitorEntity.setRequestType(MethodType.SEARCH.getTypeName());
        monitorEntity.setQuestEntity(searchRequestEntity);
        monitorEntity.setRequestDate(new Date());
        RespEntity respEntity = null;
        monitorEntity.setAirSource(searchRequestEntity.getAirSource());
        if (searchRequestEntity.getAirSource().equals(SourceEnum.AK_WEB.getSourceName())) {
            // 进行亚航的请求
            try {
                monitorEntity.setAirSource(SourceEnum.AK_WEB.getSourceName());
                respEntity = airasiaWebWorker(searchRequestEntity, airAsiaWebService, monitorEntity);
            } catch (Exception e) {
                e.printStackTrace();
            }

        } else if (searchRequestEntity.getAirSource().equals(SourceEnum.VJ.getSourceName())) {


            // 进行越捷的查询
            try {
                monitorEntity.setAirSource(SourceEnum.VJ.getSourceName());
                respEntity = VietjetairWorker(searchRequestEntity, vietjetairMobileService, vietjetairAPPService, monitorEntity);
            } catch (Exception e) {

            }
        } else if (searchRequestEntity.getAirSource().equals(SourceEnum.VJ_MOBILE.getSourceName())) {
            // 进行越捷的查询
            try {
                monitorEntity.setAirSource(SourceEnum.VJ_MOBILE.getSourceName());
                respEntity = VietjetairWorker(searchRequestEntity, vietjetairMobileService, null, monitorEntity);
            } catch (Exception e) {

            }
        } else if (searchRequestEntity.getAirSource().equals(SourceEnum.VJ_APP.getSourceName())) {
            // 进行越捷的查询
            try {
                monitorEntity.setAirSource(SourceEnum.VJ_APP.getSourceName());
                respEntity = VietjetairWorker(searchRequestEntity, null, vietjetairAPPService, monitorEntity);
            } catch (Exception e) {

            }
        } else if (searchRequestEntity.getAirSource().equals(SourceEnum.LAT.getSourceName())) {

            // 泰国狮子查询
            respEntity = LatWorker(searchRequestEntity, lionairthaiService);


        } else if (searchRequestEntity.getAirSource().equals(SourceEnum.LA_WEB.getSourceId() + "")
                || searchRequestEntity.getAirSource().equals(SourceEnum.LA_MOBILE.getSourceId() + "")) {
            respEntity = LtWorker(searchRequestEntity, lionairService);


        } else if (searchRequestEntity.getAirSource().equals(SourceEnum.JINAIR_WEB.getSourceName())) {
            respEntity = JinAirWorker(searchRequestEntity, jinairService);
        } else if (searchRequestEntity.getAirSource().equals(SourceEnum.AK_BIG_APP.getSourceName())) {
            // 亚航  big  app端
            respEntity = airasiaBigApp(searchRequestEntity, airasiaBigAppService, monitorEntity);
        } else if (searchRequestEntity.getAirSource().equals(SourceEnum.J5_WEB.getSourceName())) {
            //宿务
            respEntity = cebupacificair(searchRequestEntity, cebupacificairService);
        } else if (searchRequestEntity.getAirSource().equals(SourceEnum.FR_WEB.getSourceName())) {
            respEntity = ryanairWeb(searchRequestEntity, ryanairWebService);
        }


        log.info("查询出来的结果为-->{}",JSON.toJSONString(respEntity));
        return respEntity;
    }


    /**
     * 瑞安 web 端查询
     *
     * @param searchRequestEntity
     * @param ryanairWebService
     * @return
     */
    private RespEntity ryanairWeb(SearchRequestEntity searchRequestEntity, RyanairWebService ryanairWebService) {
        RespEntity respEntity = null;
        try {
            respEntity = ryanairWebService.searchWeb(searchRequestEntity);
        } catch (Exception e) {
            e.printStackTrace();
            return RespEntity.error("查询失败");
        }


        return respEntity;
    }

    /**
     * 宿务
     *
     * @param searchRequestEntity
     * @param cebupacificairService
     * @return
     */
    private RespEntity cebupacificair(SearchRequestEntity searchRequestEntity, CebupacificairService cebupacificairService) {
        RespEntity respEntity = null;
        try {

            respEntity = cebupacificairService.search(searchRequestEntity);
        } catch (Exception e) {
            e.printStackTrace();
            return RespEntity.error("查询失败");
        }
        return respEntity;
    }


    /**
     * 亚航 big app
     *
     * @param searchRequestEntity
     * @param airasiaBigAppService
     * @param monitorEntity
     * @return
     */
    private RespEntity airasiaBigApp(SearchRequestEntity searchRequestEntity, AirasiaBigAppService airasiaBigAppService, MonitorEntity monitorEntity) {
        RespEntity respEntity = null;

        try {
            respEntity = airasiaBigAppService.serach2(searchRequestEntity);
        } catch (Exception e) {
            e.printStackTrace();;

            return RespEntity.error("查询失败");
        }


        return respEntity;
    }


    /**
     * 亚航 web 端的查询
     *
     * @param searchRequestEntity
     * @param airAsiaWebService
     * @param monitorEntity
     * @return
     */
    private RespEntity airasiaWebWorker(SearchRequestEntity searchRequestEntity, AirAsiaWebService airAsiaWebService, MonitorEntity monitorEntity) {
        RespEntity respEntity = null;
        log.info("开始亚航的查询-----查询参数为-" + JSON.toJSONString(searchRequestEntity));
        try {
            respEntity = airAsiaWebService.serach(searchRequestEntity, monitorEntity);

        } catch (Exception e) {
            e.printStackTrace();
            return RespEntity.error("查询错误");
        }
        return respEntity;
    }

    /**
     * 越捷任务的处理
     *
     * @param searchRequestEntity
     */
    private RespEntity VietjetairWorker(SearchRequestEntity searchRequestEntity,
                                        VietjetairMobileService vietjetairMobileService,
                                        VietjetairAPPService vietjetairAPPService, MonitorEntity monitorEntity) {

        RespEntity respEntity = null;
        if (vietjetairAPPService != null && vietjetairMobileService != null) {
            int random = RandomUtil.randomInt(5);
            if (random == 0 || random == 2 || random == 4) {
// 启用 mobile端查询
                log.info("越捷mobile端请求的参数为-->>{}", JSON.toJSONString(searchRequestEntity));

                try {
                    respEntity = vietjetairMobileService.search(searchRequestEntity);
                    if (respEntity == null && respEntity.getStatus() != 200) {
                        log.info("越捷mobile端请求失败，切换为app端");
                        respEntity = vietjetairAPPService.search(searchRequestEntity);
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }
            } else {

                log.info("越捷app端请求的参数为-->>{}", JSON.toJSONString(searchRequestEntity));


                try {
                    respEntity = vietjetairAPPService.search(searchRequestEntity);
                    if (respEntity == null && respEntity.getStatus() != 200) {
                        log.info("越捷app端请求失败，切换为mobile端");
                        respEntity = vietjetairMobileService.search(searchRequestEntity);
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }

            }
        } else if (vietjetairAPPService == null && vietjetairMobileService != null) {
            // 进行 mobile的处理
            log.info("越捷mobile端请求的参数为-->>{}", JSON.toJSONString(searchRequestEntity));

            try {
                respEntity = vietjetairMobileService.search(searchRequestEntity);

            } catch (Exception e) {
                e.printStackTrace();
            }
        } else if (vietjetairAPPService != null && vietjetairMobileService == null) {
            log.info("越捷app端请求的参数为-->>{}", JSON.toJSONString(searchRequestEntity));


            try {
                respEntity = vietjetairAPPService.search(searchRequestEntity);

            } catch (Exception e) {
                e.printStackTrace();
            }

        }


        return respEntity;
    }


    /**
     * jinair 航空查询
     *
     * @param searchRequestEntity
     * @param jinairService
     * @author zhuyangxu
     */
    private RespEntity JinAirWorker(SearchRequestEntity searchRequestEntity, JinairService jinairService) {
        RespEntity respEntity = null;
        try {
            log.info("开始jinair航空查询----查询参数为--" + JSON.toJSONString(searchRequestEntity));
            respEntity = jinairService.search(searchRequestEntity);

        } catch (Exception e) {

            return RespEntity.error("查询失败");
        }

        return respEntity;
    }


    /**
     * 狮子航空查询方法
     *
     * @param searchRequestEntity
     * @param lionairService
     */
    private RespEntity LtWorker(SearchRequestEntity searchRequestEntity, LionairService lionairService) {
        RespEntity respEntity = null;
        try {
            log.info("开始狮子航空查询----查询参数为--" + JSON.toJSONString(searchRequestEntity));
            respEntity = lionairService.search(searchRequestEntity);
        } catch (Exception e) {
            e.printStackTrace();
            return RespEntity.error("查询失败");
        }


        return respEntity;

    }


    /**
     * 泰国狮子航空查询方法
     *
     * @param searchRequestEntity
     * @param lionairthaiService
     */
    private RespEntity LatWorker(SearchRequestEntity searchRequestEntity, LionairthaiService lionairthaiService) {
        RespEntity respEntity = null;
        try {
            log.info("开始泰国狮子航空查询----查询参数为--" + JSON.toJSONString(searchRequestEntity));
            respEntity = lionairthaiService.search(searchRequestEntity);


        } catch (Exception e) {

            e.printStackTrace();
            return RespEntity.error("查询失败");
        }
        return respEntity;
    }

}
