package com.bjlt.spider.business.airasia.controller;

import com.alibaba.fastjson.JSON;
import com.bjlt.spider.config.RedisService;
import com.bjlt.spider.config.Config;
import com.bjlt.spider.entity.SearchRequestEntity;
import com.bjlt.spider.business.airasia.service.AirAsiaWebService;
import com.bjlt.spider.entity.SourceEnum;
import com.bjlt.spider.entity.monitor.MonitorEntity;
import com.bjlt.spider.monitor.utils.SearchStatisticsUtil;
import com.bjlt.spider.util.RespCode;
import com.bjlt.spider.util.RespEntity;
import com.bjlt.spider.utils.DateCommonUtils;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.luyn.core.StringUtil;
import com.luyn.date.DatePattren;
import com.luyn.date.DateUtil;
import com.luyn.http.okhttp.OkHttpDownLoader;
import com.luyn.http.proxy.HttpProxy;
import com.luyn.http.response.HttpResponse;
import com.luyn.io.FileUtil;
import com.luyn.log.SysLogger;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.Calendar;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ExecutorService;

/**
 * auth : luyanan0718@163.com
 * com.bjlt.spider.controller
 * CreateTime:2017/10/18-12:06
 * introduce:    亚航
 **/
@RestController
@RequestMapping(value = "/ariasiaweb")
@Slf4j
public class AirAsiaWebController {
    private static final SysLogger logger = SysLogger.getSysLogger(AirAsiaWebController.class);


    @Autowired
    AirAsiaWebService airAsiaWebService;


    @Autowired
    Config config;


    @Autowired
    RedisTemplate redisTemplate;
//
//    @Autowired
//    ThreadPool threadPool;

    @Autowired
    RedisService redisService;

    @Autowired
    ExecutorService executorService;

    private ObjectMapper objectMapper = new ObjectMapper();

    /**
     * 查询接口
     *
     * @param searchRequestEntity
     * @return
     */
    @PostMapping(value = "/search")
    public RespEntity search(@RequestBody SearchRequestEntity searchRequestEntity) {


        // 存入redis中


        try {
            log.info("存入的key为-->{}", config.getSearchKey());
            redisService.sendChannelMess(config.getSearchKey(), JSON.toJSONString(searchRequestEntity));

            return RespEntity.success("存入成功");
        } catch (Exception e) {
            return RespEntity.error("存入失败");
        }


    }


    /**
     * 查询接口
     *
     * @param searchRequestEntity
     * @return
     */
    @PostMapping(value = "/testsearch")
    public RespEntity testSearch(@RequestBody SearchRequestEntity searchRequestEntity) {
        System.out.println("请求的参数为---" + JSON.toJSONString(searchRequestEntity));

        MonitorEntity monitorEntity = new MonitorEntity();

        monitorEntity.setResponseEntity(searchRequestEntity);
        monitorEntity.setRequestDate(new Date());
        monitorEntity.setAirSource(SourceEnum.AK_WEB.getSourceName());
        SearchStatisticsUtil.SearchTotal();//统计请求次数
        log.info("开始亚航的查询-----查询参数为-" + JSON.toJSONString(searchRequestEntity));
        try {
            RespEntity respEntity = airAsiaWebService.serach(searchRequestEntity,monitorEntity);
            logger.info(SysLogger.builder().name(searchRequestEntity.getFormCity() + "---" + searchRequestEntity.getToCity()).message("result---" + JSON.toJSONString(respEntity)).build());
//            Date endDate = new Date();
//            createLog(satrtDate, endDate, respEntity, searchRequestEntity);


            return respEntity;
        } catch (Exception e) {
            e.printStackTrace();
            return RespEntity.error(RespCode.PROGRAM_SPIDERT_ERROR, e);
        }
    }


    public void createLog(Date startDate, Date endDate, RespEntity respEntity, SearchRequestEntity searchRequestEntity) {

        // 时间统计

        long time = DateCommonUtils.differTime(endDate, startDate, Calendar.MILLISECOND);
        Map<String, Object> map = new HashMap<>(5);
        map.put("request", searchRequestEntity);
        map.put("response", respEntity);
        map.put("start", DateUtil.getFormatDate(startDate, DatePattren.TIME_FORMAT_MILLI));
        map.put("end", DateUtil.getFormatDate(endDate, DatePattren.TIME_FORMAT_MILLI));
        map.put("diffent", time + "  ms");
        String path = "syslog/";
        FileUtil.mkdir(path);
        String fileName = path + DateUtil.getFormatDate(startDate, DatePattren.DATA_FORMAT_Y10) + ".txt";
        FileUtil.writeFile(fileName, JSON.toJSONString(map) + "\n", "UTF-8", true);
    }


    @PostMapping(value = "/getindexCookie")
    public RespEntity getIndexCookie(@RequestParam(value = "ip") String ip) {
        if (StringUtil.isNotBlank(ip) && ip.contains(":")) {
            try {
                Map<String, String> headerMap = new ConcurrentHashMap<>();
                headerMap.put("accept", "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8");
                headerMap.put("accept-encoding", "gzip, deflate, br");
                headerMap.put("accept-language", "zh-CN,zh;q=0.9");
                headerMap.put("upgrade-insecure-requests", "1");
                headerMap.put("Cookie", "currencySelect=HKD");
                headerMap.put("user-agent", "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/62.0.3202.94 Safari/537.36");
                String[] strs = ip.split(":");
                HttpProxy proxyPojo = new HttpProxy();
                proxyPojo.setAddress(strs[0]);
                proxyPojo.setPort(Integer.parseInt(strs[1]));
                HttpResponse indexResponse = OkHttpDownLoader.get("https://www.airasia.com").http302Rediret(false).addProxy(proxyPojo).okhttpexecute();

                String location = indexResponse.getResponseHeaders().get("Location").toString();
                String cookie = indexResponse.getResponseCookie();
                System.out.println(location + "____" + cookie);

                return RespEntity.success(cookie);
            } catch (Exception e) {
                return RespEntity.error(RespCode.SEARCH_REQUEST_ERROR);
            }

        } else {
            return RespEntity.error(RespCode.SEARCH_REQUEST_ERROR);
        }
    }


    /**
     * 获取行李额
     *
     * @param depAirport
     * @param arrAirport
     * @return
     */
    @RequestMapping(value = "/getbaggage", method = RequestMethod.POST)
    @ResponseBody
    RespEntity getBaggage(String depAirport, String arrAirport) {
        return airAsiaWebService.getBaggage(depAirport, arrAirport);
    }


    /**
     * 验证程序
     * @param searchRequestEntity
     * @return
     */
    @RequestMapping(value = "/verify",method =  RequestMethod.POST)
    @ResponseBody
    public RespEntity verify(@RequestBody SearchRequestEntity searchRequestEntity) {
        try {
            for (int i = 0; i < 4; i++) {
                executorService.execute(new Runnable() {
                    @Override
                    public void run() {
                        // 存入redis中


                        try {
                            log.info("存入的key为-->{}", config.getSearchKey());
                            redisService.sendChannelMess(config.getSearchKey(), JSON.toJSONString(searchRequestEntity));

                            //                       return RespEntity.success("存入成功");
                        } catch (Exception e) {
                            //                       return RespEntity.error("存入失败");
                        }
                    }
                });
            }
        } catch (Exception e) {

            return RespEntity.error("存入失败");
        }


        return RespEntity.error("存入成功");


    }


    /**
     * 2018/03/14 返回参数中
     * @param searchRequestEntity
     * @return
     */
    @RequestMapping(value = "/newsearch",method = RequestMethod.POST)
    @ResponseBody
    public   RespEntity newSearch(@RequestBody SearchRequestEntity searchRequestEntity){
        return  airAsiaWebService.newSerach(searchRequestEntity);
    }


}
