package com.bjlt.spider.business.airasia.service.impl;

import com.alibaba.fastjson.JSON;
import com.bjlt.spider.account.AccountEnum;
import com.bjlt.spider.airasia.AirasiaBigRpc;
import com.bjlt.spider.airasia.dao.AirasiaBigAppDao;
import com.bjlt.spider.airasia.dao.IpDao;
import com.bjlt.spider.business.airasia.service.AirasiaBigAppService;
import com.bjlt.spider.business.common.dao.BigAppIpDao;
import com.bjlt.spider.config.Config;
import com.bjlt.spider.entity.SearchRequestEntity;
import com.bjlt.spider.entity.SearchResponseEntity;
import com.bjlt.spider.util.IpChannelIdEntity;
import com.bjlt.spider.util.MethodType;
import com.bjlt.spider.util.RespEntity;

import com.bjlt.spider.utils.CommonUtils;
import com.luyn.core.RandomUtil;
import com.luyn.core.StringUtil;
import com.luyn.http.proxy.HttpProxy;
import com.luyn.json.JsonUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.io.File;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * @author: luyanan0718@163.com
 * @create :2018/2/28 11:13
 * @introduce :
 **/

@Service
@Slf4j
public class AirasiaBigAppServiceImpl implements AirasiaBigAppService {


    @Autowired
    AirasiaBigRpc airasiaBigRpc;

    @Autowired
    AirasiaBigAppDao airasiaBigAppDao;

    @Autowired
    BigAppIpDao ipDao;

    @Autowired
    Config config;


    @Autowired
    RedisTemplate redisTemplate;


    @Override
    public RespEntity serach(SearchRequestEntity searchRequestEntity) throws Exception {

        SearchResponseEntity searchResponseEntity = null;

        log.info("请求的参数为-->{}", JSON.toJSONString(searchRequestEntity));
        HttpProxy proxy = null;
        if (config != null && config.isProxy()) {
            proxy = ipDao.getBigIp(IpChannelIdEntity.AK_APP_BIG.getChannelIdName(), MethodType.SEARCH.getTypeName());
            if (proxy == null || StringUtil.isBlank(proxy.getAddress())) {
                return RespEntity.error("获取ip 失败");
            }
        }
        if (StringUtil.isBlank(searchRequestEntity.getCurrency())) {
            searchRequestEntity.setCurrency("CNY");
        }


//
//        Map<String, String> map = new HashMap<>();
//        map.put("userName", "c06goo2q1@mail.ru");
//        map.put( "token", "c06goo2q1@mail.ru:58c4fc45708d9cac47117573d48e428e");

        Map<String, String> map = airasiaBigRpc.getRandomToken();
        if (map == null || !map.containsKey("userName")) {
            return RespEntity.error("获取token失败");
        }

        log.info("获取到的随机的token为-->{}", JSON.toJSONString(map));
        if (map != null && map.containsKey("userName") && map.containsKey("token")) {


            String userName = map.get("userName");
            String token = map.get("token");
            RespEntity signatureResp = airasiaBigAppDao.getSignature(userName, token, null);
            System.out.println(signatureResp.getAttachment());

            if (signatureResp.getStatus() == 200) {

                // 取出签名
                String signature = JSON.parseObject(signatureResp.getAttachment().toString()).getString("Signature");
                log.info("生成的签名为-->{}", signature);

                RespEntity availResp = null;
                // 获取航班信息
                availResp = airasiaBigAppDao.getGetAvailability(searchRequestEntity.getFormCity(), searchRequestEntity.getFromDate(), searchRequestEntity.getToCity(), searchRequestEntity.getRetDate(), searchRequestEntity.getTripType(), searchRequestEntity.getAdultNum(), searchRequestEntity.getChildNum(), searchRequestEntity.getCurrency(), proxy, signature, token, userName);

                if (availResp == null || availResp.getStatus() != 200) {

                    availResp = airasiaBigAppDao.getGetAvailability(searchRequestEntity.getFormCity(), searchRequestEntity.getFromDate(), searchRequestEntity.getToCity(), searchRequestEntity.getRetDate(), searchRequestEntity.getTripType(), searchRequestEntity.getAdultNum(), searchRequestEntity.getChildNum(), searchRequestEntity.getCurrency(), proxy, signature, token, userName);

                    log.info("进行第二次请求--->{}", JSON.toJSONString(searchRequestEntity));

                }


                log.info(JSON.toJSONString(availResp));
                if (availResp.getStatus() == 200) {
                    //进行解析
                    searchResponseEntity = airasiaBigAppDao.parserToSearchResponse(searchRequestEntity, availResp.getAttachment().toString());


                    searchResponseEntity.setUuid(searchRequestEntity.getUuid());
                    searchResponseEntity.setSearchId(searchRequestEntity.getSearchId());
                    searchResponseEntity.setQueneName(searchRequestEntity.getQueneName());
                    searchResponseEntity.setAdultNum(searchRequestEntity.getAdultNum());
                    searchResponseEntity.setChildNum(searchRequestEntity.getChildNum());
                    searchResponseEntity.setActionId(searchRequestEntity.getActionId());


                    if (searchResponseEntity != null) {

                        return RespEntity.success(searchResponseEntity);
                    }
                }

            }


        }


        return RespEntity.error("获取失败");


    }

    /**
     * 从reids 中获取 token 然后进行查询操作
     *
     * @param searchRequestEntity
     * @return
     */
    @Override
    public RespEntity serach2(SearchRequestEntity searchRequestEntity) {
        SearchResponseEntity searchResponseEntity = null;

        log.info("请求的参数为-->{}", JSON.toJSONString(searchRequestEntity));
        HttpProxy proxy = null;
        if (config != null && config.isProxy()) {
            proxy = ipDao.getBigIp(IpChannelIdEntity.AK_APP_BIG.getChannelIdName(), MethodType.SEARCH.getTypeName());
            if (proxy == null || StringUtil.isBlank(proxy.getAddress())) {
                return RespEntity.error("获取ip 失败");
            }
            log.info("使用的ip为-->{}",JSON.toJSONString(proxy));
        }

        if (StringUtil.isBlank(searchRequestEntity.getCurrency())) {
            searchRequestEntity.setCurrency("CNY");
        }


//
//        Map<String, String> map = new HashMap<>();
//        map.put("userName", "c06goo2q1@mail.ru");
//        map.put( "token", "c06goo2q1@mail.ru:58c4fc45708d9cac47117573d48e428e");

        //  获取token
        Set<String> keys = redisTemplate.opsForHash().keys(AccountEnum.AlreadyLogin.getAccountKey());
        if (keys == null || keys.size() <= 0) {
            return RespEntity.error("无可用key");
        }
        List<String> keysLists = CommonUtils.toList(keys);
        String hashKey = keysLists.get(RandomUtil.randomInt(keysLists.size()));
        Map<String, String> map = (Map<String, String>) redisTemplate.opsForHash().get(AccountEnum.AlreadyLogin.getAccountKey(), hashKey);

        String userName = null;
        String token = null;
        for (Map.Entry entry : map.entrySet()) {
            userName = entry.getKey().toString();
            token = entry.getValue().toString();

        }

        System.out.println(userName + "----" + token);
        if (StringUtil.isBlank(userName) || StringUtil.isBlank(token)) {
            return RespEntity.error("获取token为空");
        }


        RespEntity signatureResp = airasiaBigAppDao.getSignature(userName, token, proxy);
        System.out.println(signatureResp.getAttachment());

        if (signatureResp.getStatus() == 200) {

            // 取出签名
            String signature = JSON.parseObject(signatureResp.getAttachment().toString()).getString("Signature");
            log.info("生成的签名为-->{}", signature);
            if (StringUtil.isBlank(signature)) {
                // token失效
                try {
                    redisTemplate.opsForHash().delete(AccountEnum.AlreadyLogin.getAccountKey(), userName);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }

            RespEntity availResp = null;
            // 获取航班信息
            availResp = airasiaBigAppDao.getGetAvailability(searchRequestEntity.getFormCity(), searchRequestEntity.getFromDate(), searchRequestEntity.getToCity(), searchRequestEntity.getRetDate(), searchRequestEntity.getTripType(), searchRequestEntity.getAdultNum(), searchRequestEntity.getChildNum(), searchRequestEntity.getCurrency(), proxy, signature, token, userName);

            if (availResp == null || availResp.getStatus() != 200) {

                availResp = airasiaBigAppDao.getGetAvailability(searchRequestEntity.getFormCity(), searchRequestEntity.getFromDate(), searchRequestEntity.getToCity(), searchRequestEntity.getRetDate(), searchRequestEntity.getTripType(), searchRequestEntity.getAdultNum(), searchRequestEntity.getChildNum(), searchRequestEntity.getCurrency(), proxy, signature, token, userName);

                log.info("进行第二次请求--->{}", JSON.toJSONString(searchRequestEntity));

            }


            log.info(JSON.toJSONString(availResp));
            if (availResp.getStatus() == 200) {
                //进行解析
                searchResponseEntity = airasiaBigAppDao.parserToSearchResponse(searchRequestEntity, availResp.getAttachment().toString());


                searchResponseEntity.setUuid(searchRequestEntity.getUuid());
                searchResponseEntity.setSearchId(searchRequestEntity.getSearchId());
                searchResponseEntity.setQueneName(searchRequestEntity.getQueneName());
                searchResponseEntity.setAdultNum(searchRequestEntity.getAdultNum());
                searchResponseEntity.setChildNum(searchRequestEntity.getChildNum());
                searchResponseEntity.setActionId(searchRequestEntity.getActionId());


                if (searchResponseEntity != null) {

                    return RespEntity.success(searchResponseEntity);
                }
            }

        } else {
            try {
                redisTemplate.opsForHash().delete(AccountEnum.AlreadyLogin.getAccountKey(), userName);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }


        return RespEntity.error("获取失败");
    }
}
