
package com.bjlt.spider.business.airasia.service.impl;

import com.alibaba.fastjson.JSON;
import com.bjlt.spider.airasia.dao.AirasiaMobileDao;
import com.bjlt.spider.airasia.dao.IpDao;
import com.bjlt.spider.config.Config;
import com.bjlt.spider.entity.SearchRequestEntity;
import com.bjlt.spider.entity.SearchResponseEntity;
import com.bjlt.spider.business.airasia.service.AirasiaMobileService;
import com.bjlt.spider.util.IpChannelIdEntity;
import com.bjlt.spider.util.MethodType;
import com.bjlt.spider.util.RespEntity;
import com.luyn.core.StringUtil;
import com.luyn.http.proxy.HttpProxy;
import com.luyn.http.response.HttpResponse;
import com.luyn.io.FileUtil;
import com.luyn.log.SysLogger;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

/**
 * @author: luyanan0718@163.com
 * @create :2017/11/16 16:22
 * @introduce :  亚航  mobile端的  查询接口的实现
 **/
@Service
@Slf4j
public class AirasiaMobileServiceImpl implements AirasiaMobileService {
    private static final SysLogger logger = SysLogger.getSysLogger(AirasiaMobileServiceImpl.class);
    @Autowired
    AirasiaMobileDao airasiaMobileDao;

    @Autowired
    IpDao ipDao;
    @Autowired
    Config config;

    @Autowired
    StringRedisTemplate redisTemplate;

    @Override
    public RespEntity search(SearchRequestEntity searchRequestEntity) {
        SearchResponseEntity searchResponseEntity = null;


        HttpProxy ipEntity = null;
        // 获取首页的信息
        if (config != null && config.isProxy()) {
            ipEntity = ipDao.getIp(IpChannelIdEntity.AK_MOBILE.getChannelId() + "", MethodType.SEARCH.getTypeName());
            if (StringUtil.isBlank(ipEntity.getAddress())) {
                return RespEntity.error("获取ip失败");
            }
        } else {
            log.info("not  user ip");
        }
//

        log.info("获取到的ip为" + JSON.toJSONString(ipEntity));
//
        HttpProxy proxyPojo = new HttpProxy();
        if(ipEntity != null &&   StringUtil.isNotBlank(ipEntity.getAddress())){
            proxyPojo.setAddress(ipEntity.getAddress());
            proxyPojo.setPort(ipEntity.getPort());
        }

        System.out.println("ip----" + JSON.toJSONString(ipEntity));
//
        try {
//            HttpResponse indexResponse = airasiaMobileDao.getIndex("https://mobile.airasia.com/", ipEntity);
//
            RespEntity indexResp = airasiaMobileDao.getSearchFromRedis(redisTemplate, "AK_MOBILE_COOKIE*");
            System.out.println("首页的cookie=----" + JSON.toJSONString(indexResp));
            if (indexResp.getStatus() != 200) {

                return RespEntity.error("获取cookie 失败");
            }
            if (StringUtil.isNotBlank(indexResp.getAttachment().toString())) {
                HttpResponse flightResponse = airasiaMobileDao.getFlightLists(indexResp.getAttachment().toString(), "https://mobile.airasia.com/index.php?m=main&c=FareResult&search=1", ipEntity, searchRequestEntity);
                // 获取内容
                String html = flightResponse.asString();
                if (StringUtil.isBlank(html)) {
                    return RespEntity.error("获取到的页面为空");
                }
//                System.out.println("狗日的日志--------------------------------------" + html);

                System.out.println("----" + html);
                logger.info(SysLogger.builder().message(html).build());
//                String html = FileUtil.readFile("D:\\乐悠悠\\亚航\\亚航手机结果.txt", "utf-8");
                // 进行页面的解析
                searchResponseEntity = airasiaMobileDao.contentParser(html, searchRequestEntity);
                return RespEntity.success(searchResponseEntity);
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("采集手机mobole error", e);
        } finally {
            // 归还ip
            if (ipEntity != null && StringUtil.isNotBlank(ipEntity.getAddress())) {
                ipDao.returnIp(IpChannelIdEntity.AK_MOBILE.getChannelId() + "", ipEntity.getAddress());
            }

        }


        return RespEntity.error("search fail");
    }
}
