package com.bjlt.spider.business.lionairthai.service.impl;

import com.alibaba.fastjson.JSON;
import com.bjlt.spider.airasia.dao.IpDao;
import com.bjlt.spider.business.common.dao.BigAppIpDao;
import com.bjlt.spider.business.lionairthai.service.LionairthaiService;
import com.bjlt.spider.config.Config;
import com.bjlt.spider.entity.SearchRequestEntity;
import com.bjlt.spider.entity.SearchResponseEntity;
import com.bjlt.spider.lionairthai.dao.LionairthaiSearchDao;
import com.bjlt.spider.util.MethodType;
import com.bjlt.spider.util.RespEntity;
import com.luyn.core.StringUtil;
import com.luyn.http.proxy.HttpProxy;
import com.luyn.io.FileUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
@Slf4j
public class LionairthaiServiceImpl implements LionairthaiService {

    @Autowired
    LionairthaiSearchDao lionairthaiSearchDao;

    @Autowired
    BigAppIpDao ipDao;

    @Autowired
    Config config;

    @Override
    public RespEntity search(SearchRequestEntity searchRequestEntity) {

        try{

            if(searchRequestEntity.getUuid() == null || searchRequestEntity.getUuid().equals("")){
                log.error("请求参数不正确:"+JSON.toJSONString(searchRequestEntity));
                return RespEntity.error("请求参数不正确");
            }

            long statTime = System.currentTimeMillis();
            // 进行 非空验证
            if (StringUtil.hasBlank(searchRequestEntity.getFormCity(), searchRequestEntity.getFromDate(), searchRequestEntity.getToCity()) || searchRequestEntity.getAdultNum() <= 0) {
                System.out.println("请求参数不正确:"+JSON.toJSONString(searchRequestEntity));
                log.error("请求参数不正确:"+JSON.toJSONString(searchRequestEntity));
                return RespEntity.error("请求参数不正确");
            }
            if (StringUtil.isBlank(searchRequestEntity.getCurrency())) {
                searchRequestEntity.setCurrency("CNY");
            }
            HttpProxy proxy = null;
            if(config != null && config.isProxy()){
                proxy = ipDao.getIp("Lionairthai_Web", MethodType.SEARCH.getTypeName());
                if(proxy == null || StringUtil.isBlank(proxy.getAddress())){
                    log.error("获取ip 失败");
                    return  RespEntity.error("获取ip 失败");
                }
            }
            log.info("获取代理："+ JSON.toJSONString(proxy));
            log.info("请求："+JSON.toJSONString(searchRequestEntity));
            log.info(System.currentTimeMillis()+"");
            SearchResponseEntity searchResponseEntity = lionairthaiSearchDao.searchPc(searchRequestEntity,proxy);
            searchResponseEntity.setUuid(searchRequestEntity.getUuid());
            if(proxy != null && StringUtil.isNotBlank(proxy.getAddress())){
                ipDao.returnIp("Lionairthai_Web",proxy.getAddress()+":"+proxy.getPort());
            }
            long endTime = System.currentTimeMillis();
            log.info("响应："+JSON.toJSONString(searchResponseEntity));
       //     System.out.println("响应："+JSON.toJSONString(searchResponseEntity));
            log.info("耗时："+((endTime-statTime)/1000)+"s");
         //   System.out.println("耗时："+((endTime-statTime)/1000)+"s");
            return RespEntity.success(searchResponseEntity);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("search 失败", e);
        }
//
//        try {
////            String html = FileUtil.readFile("D:\\乐悠悠\\狮航\\狮航结果.txt", "utf-8");
////           SearchResponseEntity searchResponseEntity= lionairthaiSearchDao.analysisSearchJson(html);
////            searchResponseEntity.setFormCity(searchRequestEntity.getFormCity());//出发城市  ，三字代码
////            searchResponseEntity.setFromDate(searchRequestEntity.getFromDate());//出发时间,格式必须为YYYY-MM-DD
////            searchResponseEntity.setToCity(searchRequestEntity.getToCity());//到达城市，三字代码
////            searchResponseEntity.setRetDate(searchRequestEntity.getRetDate());//回程时间，格式必须为YYYY-MM-DD
////            searchResponseEntity.setUuid(searchRequestEntity.getUuid());
////            System.out.println(JSON.toJSONString(searchResponseEntity));
////            return RespEntity.success(searchResponseEntity);
//        } catch (Exception e) {
//            e.printStackTrace();
//        }

        return RespEntity.error("search 失败");
    }

}
