package com.bjlt.spider.business.vietjetair.controller;

import com.alibaba.fastjson.JSON;
import com.bjlt.spider.business.vietjetair.service.VietjetairAPPService;
import com.bjlt.spider.business.vietjetair.service.VietjetairMobileService;
import com.bjlt.spider.business.vietjetair.utils.VietjetairRandomRunnable;
import com.bjlt.spider.config.Config;
import com.bjlt.spider.config.RedisService;
import com.bjlt.spider.entity.SearchRequestEntity;
import com.bjlt.spider.monitor.utils.CallBackUtils;
import com.bjlt.spider.util.RespEntity;
import com.luyn.core.RandomUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.concurrent.ExecutorService;

/**
 * @author: luyanan0718@163.com
 * @create :2017/12/19 17:56
 * @introduce :      越捷的一些接口
 **/

@RestController
@RequestMapping("/vietjetair")
@Slf4j
public class VietjetairController {


    @Autowired
    VietjetairMobileService vietjetairMobileService;


    @Autowired
    VietjetairAPPService vietjetairAPPService;


    @Autowired
    Config config;

//    @Autowired
//    ThreadPool threadPool;

    @Autowired
    RedisService redisService;


    @Autowired
    ExecutorService executorService;

    /**
     * 随机 从手机端和app端查询
     *
     * @param searchRequestEntity
     */
    @RequestMapping(value = "/randomsearch", method = RequestMethod.POST)
    @ResponseBody
    public RespEntity ramdoSearch(@RequestBody SearchRequestEntity searchRequestEntity) {
        searchRequestEntity.setCurrency("VND");

        // 存入redis中

        log.info("存入的key为-->{}",config.getSearchKey());
        try {
            redisService.sendChannelMess(config.getSearchKey(), JSON.toJSONString(searchRequestEntity));

            return RespEntity.success("存入成功");
        } catch (Exception e) {
            return RespEntity.error("存入失败");
        }

    }


    /**
     * 手机端查询接口查询
     *
     * @param searchRequestEntity
     * @return
     */
    @RequestMapping(value = "/mobile/search", method = RequestMethod.POST)
    public void search(@RequestBody SearchRequestEntity searchRequestEntity) {

        log.info("越捷mobile端请求的参数为-->>{}", JSON.toJSONString(searchRequestEntity));

        try {
            RespEntity respEntity = vietjetairMobileService.search(searchRequestEntity);
            if (respEntity != null && respEntity.getStatus() == 200) {
                CallBackUtils.callBack(JSON.toJSONString(respEntity), config);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    /**
     * app查询接口查询
     *
     * @param searchRequestEntity
     * @return
     */
    @RequestMapping(value = "/app/search", method = RequestMethod.POST)
    public void searchAPP(@RequestBody SearchRequestEntity searchRequestEntity) {
        log.info("越捷app端请求的参数为-->>{}", JSON.toJSONString(searchRequestEntity));
        try {
            RespEntity respEntity = vietjetairAPPService.search(searchRequestEntity);
            if (respEntity != null && respEntity.getStatus() == 200) {
                CallBackUtils.callBack(JSON.toJSONString(respEntity), config);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    /**
     * 手机端查询测试接口查询
     *
     * @param searchRequestEntity
     * @return
     */
    @RequestMapping(value = "/mobile/testsearch", method = RequestMethod.POST)
    public RespEntity testsearch(@RequestBody SearchRequestEntity searchRequestEntity) {

        log.info("越捷mobile端请求的参数为-->>{}", JSON.toJSONString(searchRequestEntity));

        try {
            return vietjetairMobileService.search(searchRequestEntity);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return RespEntity.error("查询错误");
    }


    /**
     * app查询接口查询
     *
     * @param searchRequestEntity
     * @return
     */
    @RequestMapping(value = "/app/testsearch", method = RequestMethod.POST)
    public RespEntity testsearchAPP(@RequestBody SearchRequestEntity searchRequestEntity) {

        try {
            return vietjetairAPPService.search(searchRequestEntity);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return RespEntity.error("查询错误");
    }


    /**
     * 验证程序
     * @param searchRequestEntity
     * @return
     */
    @RequestMapping(value = "/verify",method =  RequestMethod.POST)
    @ResponseBody
    public RespEntity verify(@RequestBody SearchRequestEntity searchRequestEntity) {
        try {
            for (int i = 0; i < 5; i++) {
                executorService.execute(new Runnable() {
                    @Override
                    public void run() {
                        // 存入redis中
                        try {
                            log.info("存入的key为-->{}", config.getSearchKey());
                            redisService.sendChannelMess(config.getSearchKey(), JSON.toJSONString(searchRequestEntity));
                        } catch (Exception e) {
                        }
                    }
                });
            }
        } catch (Exception e) {

            return RespEntity.error("存入失败");
        }


        return RespEntity.error("存入成功");


    }


}
