package com.bjlt.spider.dubbo;

import com.alibaba.fastjson.JSON;
import com.bjlt.spider.business.AirChooseUtils;
import com.bjlt.spider.business.airasia.service.AirAsiaWebService;
import com.bjlt.spider.config.Config;
import com.bjlt.spider.config.RedisService;
import com.bjlt.spider.config.SpringContextHolder;
import com.bjlt.spider.entity.SearchRequestEntity;
import com.bjlt.spider.entity.SearchResponseEntity;
import com.bjlt.spider.entity.SourceEnum;
import com.bjlt.spider.entity.monitor.MonitorEntity;
import com.bjlt.spider.monitor.utils.CallBackUtils;
import com.bjlt.spider.util.MethodType;
import com.bjlt.spider.util.RespEntity;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.luyn.core.StringUtil;
import com.luyn.log.SysLogger;
import com.tripto.bjlt.interfaces.SpiderSearchRpc;
import lombok.extern.slf4j.Slf4j;
import org.springframework.context.annotation.DependsOn;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.util.Date;

@Service(value = "spiderSearchRpc")
@Slf4j
@DependsOn("springContextHolder")
public class SpiderSearchRpcImpl implements SpiderSearchRpc {

    private static final SysLogger logger = SysLogger.getSysLogger(SpiderSearchRpcImpl.class);

    Config config  = SpringContextHolder.getBean(Config.class);

    RedisService redisService = SpringContextHolder.getBean(RedisService.class);

    AirChooseUtils airChooseUtils  = SpringContextHolder.getBean(AirChooseUtils.class);

    private ObjectMapper objectMapper = new ObjectMapper();

    /**
     * 常规查询
     * @param searchRequestEntity
     * @return
     */
    public RespEntity RoutineSearch(SearchRequestEntity searchRequestEntity){
        try {
            log.info("存入的key为-->{}", config.getSearchKey());
            redisService.sendChannelMess(config.getSearchKey(), JSON.toJSONString(searchRequestEntity));
            return RespEntity.success("存入成功");
        } catch (Exception e) {
            e.printStackTrace();
            return RespEntity.error("存入失败");
        }
    }

    /**
     * 验价查询
     * @param searchRequestEntity
     * @return
     */
    public SearchResponseEntity ValidateSearch(SearchRequestEntity searchRequestEntity){
        RespEntity respEntity = airChooseUtils.workers(searchRequestEntity);
        if (respEntity.getStatus() == 200) {
            SearchResponseEntity searchResponseEntity = (SearchResponseEntity)respEntity.getAttachment();
            return searchResponseEntity;
        }
        return null;
    }

    public SearchResponseEntity airasiaWorker(SearchRequestEntity searchRequestEntity, AirAsiaWebService airAsiaWebService, MonitorEntity monitorEntity) {
        log.info("开始亚航的查询-----查询参数为-" + JSON.toJSONString(searchRequestEntity));
        try {
            RespEntity respEntity = airAsiaWebService.serach(searchRequestEntity, monitorEntity);
            if (respEntity.getStatus() == 200) {
                SearchResponseEntity searchResponseEntity = (SearchResponseEntity)respEntity.getAttachment();
                log.info("开始亚航的回调-----查询参数为-" + JSON.toJSONString(searchResponseEntity));
                monitorEntity.setCalllBackEndDate(new Date());
                return searchResponseEntity;
            }
            monitorEntity.setEndTime(new Date());
            logger.info(SysLogger.builder().logFilePath("syslog/monitor").isCreateFile(true).name("monitor").message(monitorEntity).build());
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

}
